@@ -6,8 +6,8 @@ extern crate gtk;
 
 fn main() {
     let win = nxui::window::Window { classname: DEFAULT_WINDOW_WINDOW_CLASS, title: "Hello World".to_string(), width: DEFAULT_WINDOW_WIDTH, height: DEFAULT_WINDOW_HEIGHT, x: DEFAULT_WINDOW_X, y: DEFAULT_WINDOW_Y };
-    win.show(WINDOWSTYLE_OVERLAPPED);
+    win.show(WINDOWSTYLE_OVERLAPPED,"io.github.lattesyobon.nxui");
     let msg_box = messagebox::MessageBox { title: "This is a test".to_string(), message: "Hello World".to_string() };
     // Normal Dialog
-    msg_box.show(BUTTONSTYLE_OK, DIALOGSTYLE_NONE, DIALOGHINT_MODAL);
+    msg_box.show(BUTTONSTYLE_NONE, DIALOGSTYLE_NONE, DIALOGHINT_MODAL);
 }
\ No newline at end of file
