@@ -14,7 +14,8 @@ pub struct Window {
 }
 
 impl Window {
-    pub fn show(&self,window_style: WINDOW_STYLE) {
+    #[cfg(windows)]
+    pub fn show(&self,window_style: WINDOW_STYLE,application_id: &str) {
         extern "system" fn wndproc(window: HWND, message: u32, wparam: WPARAM, lparam: LPARAM) -> LRESULT {
             unsafe {
                 match message as u32 {
@@ -74,4 +75,27 @@ impl Window {
             }
         }
     }
+
+    #[cfg(linux)]
+    pub fn show(&self,window_style: WINDOW_STYLE,application_id: &str) {
+        use gtk::prelude::*;
+
+        fn build_ui(application: &gtk::Application) {
+            let window = gtk::ApplicationWindow::new(application);
+
+            window.set_title(&*self.title);
+            window.set_border_width(10);
+            window.set_position(gtk::WindowPosition::Center);
+            window.set_default_size(self.width, self.height);
+
+            window.show_all();
+        }
+
+        let application =
+            gtk::Application::new(Some(application_id), Default::default());
+
+        application.connect_activate(build_ui);
+
+        application.run();
+    }
 }
\ No newline at end of file
